@@ -7,7 +7,7 @@ import click
 from nile.commands.compile import compile_command
 from nile.commands.install import install_command
 from nile.commands.test import test_command
-from nile.constants import BUILD_DIRECTORY
+from nile.common import BUILD_DIRECTORY
 
 
 @click.group()
